function [ys,check] = grohe_uribe03est_steadystate(ys,exo)
% computes the steady state for the NK_baseline.mod and uses a numerical
% solver to do so
% Inputs: 
%   - ys        [vector] vector of initial values for the steady state of
%                   the endogenous variables
%   - exo       [vector] vector of values for the exogenous variables
%
% Output: 
%   - ys        [vector] vector of steady state values fpr the the endogenous variables
%   - check     [scalar] set to 0 if steady state computation worked and to
%                    1 of not (allows to impos restriction on parameters)

global M_ lgy_

%global M_ 

% read out parameters to access them with their name
NumberOfParameters = M_.param_nbr;
for ii = 1:NumberOfParameters
  paramname = deblank(M_.param_names(ii,:));
  eval([ paramname ' = M_.params(' int2str(ii) ');']);
end
% initialize indicator
check = 0;

%%%% Model equations to be entered here

options=optimset(); % set options for numerical solver

        %alphaa  = 0.32;
		%rhoo    = 0.42;
		%phii    = 0.028;
		%r_w    = 0.04;		
        %gammaa  = 2;
		%omegaa  = 1.455;
		%psii    = 0.000742;
		%deltaa  = 0.1;
		%sigmae = 0.0129;
        
        
		betaa   = 1/(1+r_w);
        
		h_ss   = ((1-alphaa)*(alphaa/(r_w+deltaa))^(alphaa/(1-alphaa)))^(1/(omegaa-1)); 
		k_ss   = h_ss/(((r_w+deltaa)/alphaa)^(1/(1-alphaa)));
		inv_ss   = deltaa*k_ss;                                                     
		y_ss   = (k_ss^alphaa)*(h_ss^(1-alphaa));                                   
		d_bar  = 0.7442;
		d_ss   = d_bar;                                                        
		c_ss   = y_ss-inv_ss-r_w*d_ss;
		tb_ss  = y_ss-c_ss-inv_ss;




        
% vars
    d     = d_ss;
    c     = log(c_ss);
    h     = log(h_ss); 
    y     = log(y_ss);
    inv     = log(inv_ss);
    k     = log(k_ss);
    a=0;
    lambdaa= log((exp(c)-((exp(h)^omegaa)/omegaa))^(-gammaa));
    tb    =  1-((exp(c)+exp(inv))/exp(y));
    ca=0;
    riskpremium=0;
    r     = log((1-betaa)/betaa);
    y_obs=0.012;
    
    
%% end own model equations

for iter = 1:length(M_.params) %update parameters set in the file
  eval([ 'M_.params(' num2str(iter) ') = ' M_.param_names(iter,:) ';' ])
end

NumberOfEndogenousVariables = M_.orig_endo_nbr; %auxiliary variables are set automatically
for ii = 1:NumberOfEndogenousVariables
  varname = deblank(M_.endo_names(ii,:));
  eval(['ys(' int2str(ii) ') = ' varname ';']);
end


